package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!`````",```````!``````````'"Q````
M`````````$``.``)`$``'@`=``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````<`````````!P``````````0`````````!````
M!0```````````````````````````````````(BA````````B*$`````````
M$`````````$````&````D*L```````"0NP```````)"[````````L`0`````
M```@!0`````````0`````````@````8```"XJP```````+B[````````N+L`
M```````P`@```````#`"````````"``````````$````!````%0"````````
M5`(```````!4`@```````$0`````````1``````````$`````````%#E=&0$
M````K)D```````"LF0```````*R9````````%`$````````4`0````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````)"K````````D+L```````"0NP``
M`````'`$````````<`0````````!`````````"]L:6(V-"]L9"UL:6YU>"UX
M.#8M-C0N<V\N,@`$````%`````,```!'3E4`Y'UPOV785R!.C!I.J/`/FVV'
M;/<$````$`````$```!'3E4```````,````"`````````&$```!B````````
M``````!'````!```````````````)@``````````````)````!H`````````
M.`````@```!8`````````!4```!!````0@```#H```!1````7@````8````Y
M```````````````#````5````#P``````````````$0```!,````2```````
M````````80````P`````````+``````````S`````````$D```!3````0```
M`#0`````````70```%<`````````$P````<``````````````$L````@````
M+@```"4`````````````````````````%P`````````````````````````!
M````'P````H````]````7P```#L`````````(P```%4```!&````)P```%``
M``!#````,````"T`````````/@```````````````````%8```!%````````
M`"@```!-````+P````L````R`````@``````````````````````````````
M`````````````````````````````````````%D`````````````````````
M````````````````````````````````````8``````````6````````````
M````````7````!(`````````$0````````!:`````````%(````B````````
M`#\``````````````"$``````````````"L````;````````````````````
M*@`````````8```````````````V`````````#4````)````6P```#<````Q
M````*0`````````````````````````/```````````````%`````````!D`
M```<````'0`````````>`````````!0````0````#0``````````````````
M`$H```````````````````!.``````````X`````````````````````````
M3P```````````````````!$````_````!`````@````@'!``!4`$AB@"0`20
MA@"$@@D`($D@!`BXHA%-N@`&"@`````_````0@```$4```!&````3@```$\`
M``!1````50```%8```!8````60```%P```!>````8```````````````;L7?
M'\[>1RUK?YI\+L6;MB#_Y`[59-1\V7%8'.)'Q@%"^M>'K$OCP/+;TQVZXY)\
MPN4_+/JA;&"S`8MO:PE#UF:OS&;%N9Q`0D75[,2)!9"(!W#3.?*+'`T4XI[:
MS>.>,V+;[16,)<P,.I<+5J2;EJ?=HVM^J9R;T67.;>"G`@IK&IY0"HH05Z/@
M^TD```````````````````````````````#A````$@``````````````````
M``````"A`0``$@`````````````````````````"`@``$@``````````````
M``````````#8`0``$@`````````````````````````!````(```````````
M```````````````)`@``$@````````````````````````"'`@``$@``````
M```````````````````>`@``$@````````````````````````!%`0``$@``
M``````````````````````!O`@``$@````````````````````````!G`@``
M$@````````````````````````!T````$@````````````````````````!:
M`P``$@````````````````````````#<````$@``````````````````````
M``!!`@``$@`````````````````````````S`@``$@``````````````````
M``````#Q`0``$@````````````````````````"``@``$@``````````````
M``````````"0`@``$@````````````````````````#@`0``$@``````````
M```````````````W`0``$@`````````````````````````%`0``$@``````
M``````````````````!S`0``$@````````````````````````#H`0``$@``
M``````````````````````#P`@``$@````````````````````````!@`0``
M$@`````````````````````````7`@``$@````````````````````````"5
M`0``$@````````````````````````#4`@``$@``````````````````````
M``#-`@``$@`````````````````````````3`0``$@``````````````````
M```````=````(`````````````````````````!5`@``$@``````````````
M``````````!4````$@````````````````````````#&`0``$@``````````
M``````````````"R`0``$@````````````````````````!L`0``$@``````
M``````````````````"#````$@````````````````````````"/````$@``
M```````````````````````L`0``$@````````````````````````#R````
M$@````````````````````````!&````$@````````````````````````#F
M````$@````````````````````````!5`0``$@``````````````````````
M``#`````$@`````````````````````````/`@``$@``````````````````
M``````":`0``$@````````````````````````"^`@``$@``````````````
M``````````"7`@``$@````````````````````````!C````$@``````````
M``````````````#&`@``$@`````````````````````````L`@``$@``````
M``````````````````"D````$@`````````````````````````C`0``$@``
M``````````````````````!<`@``$@````````````````````````#3`0``
M$@````````````````````````"-`0``$@````````````````````````!'
M`@``$@`````````````````````````L````(```````````````````````
M```E`@``$@`````````````````````````Z`@``$@``````````````````
M``````"P`@``$@````````````````````````!C`P``$@`/`"`]````````
M7@````````"/`P``$@`/`)`S````````]P8```````#A`@``$@`/`,`@````
M````-`(````````W`P``$@`/`.`M````````!0`````````C!```$@`/`/`M
M````````&@(```````!9!```$@`/`)`Z````````C0(````````/!```$``;
M`$#```````````````````!V`P``$@`/`!`P````````(@````````"<`P``
M$@`/`/!3````````D@$```````"T`P``$0`1`)A8````````!`````````!^
M`0``$0`6`*"[````````$P````````#S`P``$``;`+#`````````````````
M```;!```$@`/`)`L````````,``````````P!```$@`/`+`R````````W```
M``````!"!```$@`/`"`R````````70````````"G`P``$``9``#`````````
M``````````"#`P``$@`/`$`P````````1`````````#F`@``$0`;`&C`````
M````"`````````!O`P``$``:`$#```````````````````#G`@``(0`;`&C`
M````````"`````````#I`P``$0`9`"#`````````"`````````!Y`@``$0`;
M`(#`````````"``````````G`P``$@`/`%Y8````````!`````````#9`P``
M$@`/`-Y7````````9P````````"M`P``$@`/```C````````*P````````!0
M!```$@`/`)!3````````5`````````"I`P``(``9``#`````````````````
M``#1````$0`;`$#`````````!`````````#H`@``(0`;`&C`````````"```
M``````!(`P``$@`/`(`R````````)`````````"A`@``(@``````````````
M``````````##`P``$@`/`!`M````````P0`````````%!```$@`/`)!5````
M````,P(```````"S````$0`;`&#``````````0````````#X`P``$@`/`)`P
M````````A@$`````````7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%]?
M9VUO;E]S=&%R=%]?`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S
M>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?
M8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E
M<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,
M7W1H<E]K97D`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N
M;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!0
M97)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?
M<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y
M7W=R87``;'-E96LV-`!R96%D`&]P96XV-`!?7V5R<FYO7VQO8V%T:6]N`'!T
M:')E861?9V5T<W!E8VEF:6,`7U]S='!C<'E?8VAK`&5X:70`<W1R;F-M<`!S
M=')R8VAR`&-L;W-E9&ER`%]?<W1A8VM?8VAK7V9A:6P`=6YL:6YK`&UK9&ER
M`')E86QL;V,`;65M8VAR`&=E='!I9`!S=')D=7``<W1R=&]K`'-T<FQE;@!S
M=')S='(`<FUD:7(`7U]F<')I;G1F7V-H:P!M96UC<'D`7U]L>'-T870V-`!O
M<&5N9&ER`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED`')E861L:6YK`'-T<F-H
M<@!R96%D9&ER-C0`7U]C>&%?9FEN86QI>F4`7U]S<')I;G1F7V-H:P!M96UM
M;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N
M`%]?<F5G:7-T97)?871F;W)K`&QI8G!E<FPN<V\`;&EB<'1H<F5A9"YS;RXP
M`&QI8F,N<V\N-@!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?97AE8P!G
M971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?961A=&$`
M<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!S:&%?=7!D
M871E`%]?9&%T85]S=&%R=`!?24]?<W1D:6Y?=7-E9`!P87)?8W5R<F5N=%]E
M>&5C7W!R;V,`7U]L:6)C7V-S=5]I;FET`&UY7W!A<E]P;`!?96YD`'!A<E]I
M;FET7V5N=@!S:&%?9FEN86P`7U]B<W-?<W1A<G0`>'-?:6YI=`!P87)?9FEN
M9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!S:&%?:6YI
M=`!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXR+C4`1TQ)0D-?,BXS
M+C0`1TQ)0D-?,BXQ-`!'3$E"0U\R+C,N,@!'3$E"0U\R+C0`+W5S<B]L:6(O
M<&5R;#4O-2XR-BXQ+W@X-E\V-"UL:6YU>"UT:')E860M;75L=&DO0T]210``
M```"``,``@`"``$``@`"``(``0`"``(``0`"``$``@`"``0``@`"``(``0`!
M``$``@`%``$``@`#``(``@`!``$`!@`!``<``P`"``$``0`!``$``0`!``$`
M`0`"``,``@`"``$``@`"``$``0`"``(``P`'``$``@`"``<``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``(``0`"``$``@`!``$``0`!``$`
M`0`"``$``@`!``$``0`!``````````$``0`-`P``$````"````!U&FD)```#
M`&\$`````````0`%`!T#```0`````````'09:0D```<`>P0``!````"4D98&
M```&`(<$```0````<AEI"0``!0"2!```$````!1I:0T```0`G@0``!````!U
M&FD)```"`&\$````````D+L````````(```````````D````````F+L`````
M```(`````````,`C````````",`````````(``````````C`````````(,``
M```````(`````````'!;````````*,`````````(`````````-!7````````
M,,`````````(`````````%!8````````.,`````````(`````````'!8````
M````N+\````````&````!0``````````````P+\````````&````"0``````
M````````R+\````````&````'0``````````````T+\````````&````(```
M````````````V+\````````&````*0``````````````X+\````````&````
M,@``````````````Z+\````````&````.P``````````````\+\````````&
M````70``````````````H+L````````%````20``````````````0,``````
M```%````6@``````````````8,`````````%````8```````````````:,``
M```````%````4```````````````@,`````````%````5```````````````
M`+X````````'`````0``````````````"+X````````'`````@``````````
M````$+X````````'`````P``````````````&+X````````'````!```````
M````````(+X````````'````!@``````````````*+X````````'````!P``
M````````````,+X````````'````"```````````````.+X````````'````
M"@``````````````0+X````````'````"P``````````````2+X````````'
M````#```````````````4+X````````'````#0``````````````6+X`````
M```'````#@``````````````8+X````````'````#P``````````````:+X`
M```````'````$```````````````<+X````````'````$0``````````````
M>+X````````'````$@``````````````@+X````````'````$P``````````
M````B+X````````'````%```````````````D+X````````'````%0``````
M````````F+X````````'````%@``````````````H+X````````'````%P``
M````````````J+X````````'````&```````````````L+X````````'````
M&0``````````````N+X````````'````&@``````````````P+X````````'
M````&P``````````````R+X````````'````'```````````````T+X`````
M```'````'@``````````````V+X````````'````'P``````````````X+X`
M```````'````(0``````````````Z+X````````'````(@``````````````
M\+X````````'````(P``````````````^+X````````'````)```````````
M`````+\````````'````)0``````````````"+\````````'````)@``````
M````````$+\````````'````)P``````````````&+\````````'````*```
M````````````(+\````````'````*@``````````````*+\````````'````
M*P``````````````,+\````````'````+```````````````.+\````````'
M````+0``````````````0+\````````'````+@``````````````2+\`````
M```'````+P``````````````4+\````````'````,```````````````6+\`
M```````'````,0``````````````8+\````````'````,P``````````````
M:+\````````'````-```````````````<+\````````'````-0``````````
M````>+\````````'````-@``````````````@+\````````'````-P``````
M````````B+\````````'````.```````````````D+\````````'````.0``
M````````````F+\````````'````.@``````````````H+\````````'````
M/```````````````J+\````````'````/0``````````````L+\````````'
M````/@``````````````2(/L"$B+!;6B``!(A<!T`O_02(/$",,`````````
M``#_-;J@``#_);R@```/'T``_R6ZH```:`````#IX/____\ELJ```&@!````
MZ=#_____):J@``!H`@```.G`_____R6BH```:`,```#IL/____\EFJ```&@$
M````Z:#_____)9*@``!H!0```.F0_____R6*H```:`8```#I@/____\E@J``
M`&@'````Z7#_____)7J@``!H"````.E@_____R5RH```:`D```#I4/____\E
M:J```&@*````Z4#_____)6*@``!H"P```.DP_____R5:H```:`P```#I(/__
M__\E4J```&@-````Z1#_____)4J@``!H#@```.D`_____R5"H```:`\```#I
M\/[___\E.J```&@0````Z>#^____)3*@``!H$0```.G0_O___R4JH```:!(`
M``#IP/[___\E(J```&@3````Z;#^____)1J@``!H%````.F@_O___R42H```
M:!4```#ID/[___\E"J```&@6````Z8#^____)0*@``!H%P```.EP_O___R7Z
MGP``:!@```#I8/[___\E\I\``&@9````Z5#^____)>J?``!H&@```.E`_O__
M_R7BGP``:!L```#I,/[___\EVI\``&@<````Z2#^____)=*?``!H'0```.D0
M_O___R7*GP``:!X```#I`/[___\EPI\``&@?````Z?#]____);J?``!H(```
M`.G@_?___R6RGP``:"$```#IT/W___\EJI\``&@B````Z<#]____):*?``!H
M(P```.FP_?___R6:GP``:"0```#IH/W___\EDI\``&@E````Z9#]____)8J?
M``!H)@```.F`_?___R6"GP``:"<```#I</W___\E>I\``&@H````Z6#]____
M)7*?``!H*0```.E0_?___R5JGP``:"H```#I0/W___\E8I\``&@K````Z3#]
M____)5J?``!H+````.D@_?___R52GP``:"T```#I$/W___\E2I\``&@N````
MZ0#]____)4*?``!H+P```.GP_/___R4ZGP``:#````#IX/S___\E,I\``&@Q
M````Z=#\____)2J?``!H,@```.G`_/___R4BGP``:#,```#IL/S___\E&I\`
M`&@T````Z:#\____)1*?``!H-0```.F0_/___R4*GP``:#8```#I@/S___\E
M.I\``&:0``````````!54TB#[#B)?"0<2(ET)!!(C7PD'$B)5"0(2(UT)!!(
MC50D"&1(BP0E*````$B)1"0H,<#H&/[__TB+-=F>``!(BSW:G@``2(GRZ'`W
M``"`/4N?````=2_H9/W__TB%P$B)!8*?```/A+X!``!(B<?HG/S__XL]!I\`
M`.CQ_?__QH#1"````(L]])X``.C?_?__@(BJ!````HL]XIX``.C-_?__@(BJ
M!````8M$)!R->`2-6`-(N/________\?2&/_2#G'#X<B`0``2,'G`^@=_?__
M2(M\)!!(C0V].```1(M$)!Q(B07UG@``2(L72(E("$B-#:8X``!!@_@!2(E(
M&$B)$$B+%56>``!(B5`0#X[-````2(/'"$&#P`.^!````&8/'T0``$B+#TAC
MUH/&`4B#QPA$.<9(B0S0=>I(8_9(P>8#2(L]G)X``$C'!#``````2(TUI0H`
M`$4QP(G:2(G!Z'C]__^%P(G#=&1(BSUSG@``2(UL)"3H(?S__TB-/?8V```Q
MP$B)[NC``0``2(7`="I(BSU,G@``Z(_[___H&OW__XG82(M<)"AD2#,<)2@`
M``!U;4B#Q#A;7<-(BST2G@``2(7_=#;HD!H``.O#2(L]#YX``.B2_?__B</K
MC+X@````Z5G___](C37MF```2(T]-#8``#'`Z)_\__](C3TI-@``2(GNZ$`!
M``!(A<!(B<=(B06[G0``#X1R____ZZ;H-OO__[\!````Z%S]__]F+@\?A```
M````9I`Q[4F)T5Y(B>)(@^3P4%1,C05(-0``2(T-P30``$B-/9S]____%9Z<
M``#T#Q]$``!(C3WQG```54B-!>F<``!(.?A(B>5T&4B+!6J<``!(A<!T#5W_
MX&8N#Q^$``````!=PV9F+@\?A```````#Q\`2(T]L9P``$B--:J<``!52"G^
M2(GE2,'^`TB)\$C!Z#](`<9(T?YT&$B+!4F<``!(A<!T#%W_X&8/'X0`````
M`%W#9F8N#Q^$```````/'P"`/<&<````=2](@ST?G````%5(B>5T#$B+/2J<
M``#HS?S__^A(____Q@69G````5W##Q^``````//#9@\?1```54B)Y5WI9O__
M_V8/'T0``$%7059!54%455-(@^P(2(7_#X2Q````3(L].IP``$V%_P^$H0``
M``^V!X3`=`0\/75>13'D28L?2(7;=#E)B?5)B?Y-8^1,B?T/'X``````3(GB
M3(GV2(G?Z`+Y__^%P'4'0H`\(SUT1TB#Q0A(BUT`2(7;==I(@\0(2(G86UU!
M7$%=05Y!7\,/'X0``````$F)_$F#Q`%!#[8$)(3`=`0\/77O02G\ZXP/'X``
M````3"G]2HU<(P%(P?T#08EM`.NT9@\?1```,=OKJ@\?0`!54TB)_4B#[!AD
M2(L$)2@```!(B40D"#'`2(U<)`1FD#'`2(G>2(GOZ`/___](A<!T-DAC5"0$
M2(L%2IL``$B-!-!(BU`(2(722(D0=-)FD$B#P`A(BU`(2(722(D0=?#KOF8/
M'T0``$B+1"0(9$@S!"4H````=0=(@\086UW#Z+SX__]F9BX/'X0``````)!!
M5T%6055!5%532(GS2(G]2(/L*&1(BP0E*````$B)1"08,<`QP(`^/0^4P$@!
MPTB)W^AI^/__2(UT)!1)B<1(B>\QP.A7_O__2(7`#X0.`0``2(G'28G%Z$/X
M__],.>`/@^(```!,8W0D%$G!Y@,/MD4`A,`/A*T!```\/0^$I0$``$B)Z.L-
M#Q^$``````"`^CUT"TB#P`$/MA"$TG7P2"GH2)A,`S5,F@``2HU\(`+H&OG_
M_TB%P$F)!@^$>P$``$AC5"042(L%*IH``$B-30%(BQ30#[9%`#P]B`)T)H3`
M=1#K(&8N#Q^$```````\/7022(/!`0^V0?](@\(!A,"(`G7JQ@(],<`/'T0`
M``^V#`.(3`(!2(/``83)=?`QP$B+="089$@S-"4H````#X41`0``2(/$*%M=
M05Q!74%>05_##Q\`2(/#`0^V0_])@\4!A,!!B$7_=>SKPF:03(L]D9D``$F#
M/P`/A+\```!,B?@QTNL+#Q^$``````!$B>I(@\`(1(UJ`4B#.`!U[XUR`TAC
M]DC!Y@.+!7^9``"%P'5;2(GWQP5NF0```0```.@9^/__2(7`#X1]````36/%
M3(G^2(G'3HTTQ0````!,B40D"$R)\NB2^/__3(M$)`A(B<%(B04+F0``2L=$
MP0@`````1(EL)!3I;_[__TR)_^A(^/__2(7`2(G!2(D%XY@``'0F36/%3HTT
MQ0````#KR0\?0``QP.EV_O__D+X0````13'MZ5[___^X_____^G;_O__Z&3V
M__\/'T``05=!5D%505154TB![+@```!D2(L$)2@```!(B80DJ````#'`2(7_
M=`B`/P!)B?YU+TB+A"2H````9$@S!"4H````#X4L`0``2('$N````%M=05Q!
M74%>05_#9@\?1```Z)OU__](A<!(B<-TQ$B-1"002(TM9#```$R-)5PP``!,
MC3U8,```2(D$)$B)W^B=]___2(7`#X2\````3(U($[D"````2(GO3(G.\Z8/
ME\`<`(3`=-6Y`P```$R)SDR)Y_.F#Y?`'`"$P'2_3(GW3(E,)`CH=_7__TR+
M3"0(28G%3(G/Z&?U__]!C7P%`DAC_^B*]O__3(M,)`A)B<5(B<=-B?!,B?E(
MQ\+_____O@$````QP.C&]___2(L4)+\!````3(GNZ,7T__^#^/],B>]T$(M$
M)"@E`/```#T`0```="KH6/3__TR)[^@P]/__Z3;___\/'P!(B=_H</7__TR)
M]^C8]/__Z<3^___HCO[__^O4Z.?T__\/'X``````4TB)_DB)^[\!````2('L
MH````$B)XF1(BP0E*````$B)A"28````,<#HTO;__X7`=3Z+5"08@>(`\```
M@?H`0```=#2!^@"@``!T+$B+C"28````9$@S#"4H````=3!(@<2@````6\,/
M'X0``````#'`Z]@/'T``O@(```!(B=_H._;__X7`#Y3`#[;`Z[WH3/3__V9F
M+@\?A```````D$%6055)B?9!5%5)B?Q32(T]L"X``+K_#P``2('L$!```$B)
MXTB)WF1(BP0E*````$B)A"0($```,<#H<?/__X7`#XZ)````C5#_1(LM#Y8`
M`$ACZH`\+`!T5DACZ$B)ZKXO````2(G?Z'/T__](A<!T1D2)[^C6]/__2(GI
M2(G:3(GF2(G'Z+7U__](BX0D"!```&1(,P0E*````'4[2('$$!```%M=05Q!
M74%>PV:0A=)UJ0\?0`!$B>_HD/3__TR)\DR)YDB)Q^C"\___Z[M$BRV)E0``
MZ]_H8O/__V:04TB)_KH`$```2('L$!```$B)XTB)WV1(BP0E*````$B)A"0(
M$```,<#H,O3__TB#Z`%(.=AW%>L8#Q^``````,8``$B#Z`%(.=AT!8`X+W3O
MOB\```!(B=_H,O/__TB%P'0U2#G8=RA(B=_H4/7__TB+C"0($```9$@S#"4H
M````=3Q(@<00$```6\,/'T``Q@``Z],/'P!(BX0D"!```&1(,P0E*````'44
M2('$$!```$B-/20M``!;Z0'U___HG/+__V9F+@\?A```````D$%45;H"````
M4S'V08G\2('L$``!`&1(BP0E*````$B)A"0(``$`,<#HH_3__TB-:/](B>I(
MP?H_2,'J,$B-1!4`#[?`2"G02"G%#XB4````2(GC#Q]$```QTDB)[D2)Y^AK
M]/__N@@``0!(B=Y$B>?HR_+__TB82(/X!W932(U$`_A(.=AR24B-%?*3``#K
M"4B#Z`%(.=AR-TB+"D@Y"'7O2"G=2`'H2(NT)`@``0!D2#,T)2@```!U,TB!
MQ!```0!;74%<PV8N#Q^$``````!(@>T```$`2(']``#__P^%=/___TC'P/__
M___KNNB>\?__9F8N#Q^$```````/'P!(@^P(BSVFDP``Z)'R__](BQ4:DP``
M2(T-\VP``$B--0`L``!(B<=(@\0(Z;#R__](@^P(BSUVDP``Z&'R__](B<?H
MN?___XL]8Y,``.A.\O__3(T%4"T``$B-%:`-``!(C379*P``13')2(G'2(/$
M"$R)P>FG\O__#Q^``````%532('L*"```&1(BP0E*````$B)A"08(```,<!(
MB>-(C:PD$!```.AD\/__3(T-;2L``$B-#9LK``!!B<"Z`1```+X!````2(G?
M,<#H/_/__[H`$```2(GN2(G?Z!_P__^%P'A3C7@!2(G#2&/_Z+WQ__](A<!(
MB<%T&$ACVTB)[DB)QTB)VNAD\?__2(G!Q@08`$B+E"08(```9$@S%"4H````
M2(G(=1-(@<0H(```6UW##Q]$```QR>O7Z$_P__]F9BX/'X0```````\?0`#I
M*____V9F+@\?A```````05=!5D%5051)B?154TB)^TB-/>HJ``!(@>RX$```
M9$B+!"4H````2(F$)*@0```QP$B-="0,Z.7U__^^+P```$B)WTB)Q>@%\/__
M2(7`=$!(C3VS*@``2(G>,<#H'_?__TB)V$B+C"2H$```9$@S#"4H````#X6:
M`0``2('$N!```%M=05Q!74%>05_##Q\`3(GGZ/CQ__](C35X*@``2(G'Z'GQ
M__](A<!)B<=TH4&`/P!,C:0DH````$R-;"00#X3K````9BX/'X0``````$B%
M[7033(G^2(GOZ!#P__^%P`^$I0```$R)_^@P[___28U4!_])B<9).==S)X`Z
M+W0+ZR`/'T``@#HO=0S&`@!(@^H!23G7=>],B?_H_^[__TF)QDB)W^CT[O__
M28U$!@%(/?\/```/AQ/___](@^P(2(T-O"H``$R-#<HI``!338GXN@`0``"^
M`0```$R)YS'`Z$GQ__],B>I,B>:_`0```.A)[O__A<!:6740BT0D*"4`\```
M/0"```!T6TB--8,I```Q_^B%\/__2(7`28G'#X2I_O__08`_``^%'____TB%
M[70:2(T]\"@``+D"````2(GN\Z8/E\`<`(3`=+U!O@$```!,C3W0*```Z4+_
M__]F#Q]$``"^`0```$R)Y^@;\/__A<!UE$B-/0HI``!,B>;H>/7__TR)Y^B`
M\/__Z4_^___H%N[__V8/'T0``%.^+P```$B)^^@R[O__2(U0`4B%P$@/1=I(
MB=];Z4[P__]F9BX/'X0```````\?`$B%_W0K@#\`="932(G[Z+WM__](@\`!
M2#T`$```=R%(B=];Z5CZ__\/'X0``````$B-/28H``#I!/#__P\?0``QP%O#
M9F8N#Q^$``````"04TB-/7,H``!(@^P09$B+!"4H````2(E$)`@QP$B-7"0$
MZ"KT__](C3U7*```,<#H'/3__TB-/5$H```QP.@.]/__2(T]3"@``#'`Z`#T
M__](C3U%*```,<#H\O/__TB-/4<H```QP.CD\___2(T][B<``#'`Z-;S__](
MC3TW*```,<#HR//__TB-/3,H```QP.BZ\___2(T]+R@``#'`Z*SS__](C3V_
M)P``,<#HGO/__TB-/1TH```QP$B)WNB]\O__2(7`=!%(C3WS)P``2(G&,<#H
M!_3__TB-/0<H```QP$B)WNB6\O__2(7`=!%(C3T#*```2(G&,<#HX//__TB-
M/?TG```QP$B)WNAO\O__2(7`=$)(C3U$)P``2(G&,<#HN?/__TB--?<G``!(
MC3UG)P``,<#HI//__TB+1"0(9$@S!"4H````=35(@\006\-F#Q]$``!(C3VU
M)P``,<!(B=[H%_+__TB%P'2Y2(T]0R<``$B)QC'`Z&'S___KIN@*[/__9BX/
M'X0``````$B#[!A(C3T=)P``9$B+!"4H````2(E$)`@QP$B-="0$Z,OQ__\Q
MTDB%P'05#[8`/#`/E,*$P`^4P`G"@_(!#[;22(M,)`AD2#,,)2@```")T'4%
M2(/$&,/HH^O__P\?`$B#[`CHI^O__XG'Z%#K__](A<!T"TB+`$B#Q`C##Q\`
M,<#K]&9F+@\?A```````D$%454B)_5-(C3WY)@``2(/L$&1(BP0E*````$B)
M1"0(,<!(C70D!.@T\?__2(7`2(GN='R`.`!(B<-T=$B)Q^B<[?__2(7`=75(
MB>_H#^O__TB)WTF)Q.@$Z___28U\!`+H*NS__TB#[`A,C0WF)0``2(T-S"8`
M`%-(Q\+_____2(G'28G$28GHO@$````QP.A;[?__2(T]:R8``$R)YC'`Z!KR
M__]86NL49@\?1```2(T]4"8``#'`Z`+R__](BT0D"&1(,P0E*````'4)2(/$
M$%M=05S#Z)3J__\/'T``05=!5D%5051)B?U54TB-/4TE``!(@>QX`0``9$B+
M!"4H````2(F$)&@!```QP$B-!0XF``!,C60D'$C'1"0P`````$C'A"2(````
M`````$C'1"10`````$B)1"0@2(T%J20``$R)YDB)1"0H2(T%AB4``$B)1"1@
M2(T%<R4``$B)1"1H2(T%O24``$B)1"1P2(T%>"4``$B)1"1X2(T%K24``$B)
MA"2`````2(T%A24``$B)1"1`2(T%EB4``$B)1"1(,<#HMN___TB%P'0)@#@`
M#X5H`@``,<#H$?[__TB%P$B)PP^$I0(``$B)W^B-Z?__2(U\``'HL^K__X`[
M`$F)QG0U3(T]424``$R)]9!$#[8#2(GO,<!,B?E(Q\+_____O@$```!(@\,!
M2(/%`NC;Z___@#L`==9(C5PD8$B-/;,D``#K&`\?A```````2(/#"$B+.TB%
M_P^$@`$``#'`3(GFZ!;O__](A<!(B<5TWH`X`'392(G'Z#'T__^%P'3-2(GO
MZ&7K__](A<!(B<,/A$D!``!F#Q^$``````!(B=J+"DB#P@2-@?_^_O[WT2'(
M)8"`@(!TZ8G!P>D0J8"````/1,%(C4H"2`]$T8G!`,%,B?%(@]H#2"G:BS%(
M@\$$C8;__O[^]]8A\"6`@("`=.F)QL'N$*F`@```#T3&2(UQ`D@/1,Z)QD``
MQDB#V0-,*?&-K`H$!```2&/M2(GOZ(GI__])B<=(C04Z)```059,C0T_(P``
M2(T-(20``$F)V%!(Q\+_____O@$```!,B?\QP.BUZO__3(G_OL`!``#HB.?_
M_X/X_U]!6'42Z$OG__]$BPA!@_D1#X5(!```2(V4))````!,B?Z_`0```.@9
MZO__A<")PW47BX0DJ````"4`\```/0!````/A$P!``!)BTT`2(L],8H``$B-
M%5(D``!-B?B^`0```#'`,>WH">K__^F$````#Q]``#'M9@\?1```2&/%2(M<
MQ"!(A=MT.X`[`'0V2(G?@\4!Z*OR__^%P'3?2(G?Z-_I__](A<!(B<,/A8/^
M__](8\5(BUS$($B%VW7+9@\?1```,=OI:?[__V8/'X0``````$B)QTB)1"0(
MZ-/[__](BT0D"$B)Q^B6Z?__2(G%#Q\`2(N4)&@!``!D2#,4)2@```!(B>@/
MA7@#``!(@<1X`0``6UU!7$%=05Y!7\,/'T``2(T]H"(``#'M2(7_="9FD#'`
M3(GF@\4!Z-/L__](A<!T!8`X`'4I2&/%2(M\Q$!(A?]UW+\-````2(T=;"(`
M`.C;Y___28G&Z2C]__\/'P!(B<?H".G__TB%P$B)PP^%]_S__^O!9BX/'X0`
M`````$2+M"2L````Z)/F__]!.<8/A9[^__^+A"2H````)?\!```]P`$```^%
MA_[__TB)[^A[Y___2(T]]B$``$B)Q4R)YC'`Z#?L__](A<`/A%X!``!)BWT`
M2(G&Z`+V__](A<!)B<0/A$8!``!,B>?H#N;__X/X`WY!2&/02(T][R$``+D%
M````28UT%/SSI@^7PH#:`(32=2&#^`0/A.@!``"#Z`1(F$&`?`3_+P^$UP$`
M``\?@``````QP.C1^?__A<!U%3'V3(GGZ'/G__^%P$&)Q`^%Z````$B--48A
M``!(C3W2(```3(TEO"$``#'`3(TM@R```.CE[/__Z!#E__]!5$R-#7`@``!0
M2(T->"$``$C'PO____]-B?B^`0```$B)[S'`Z.;G__]86NM#9I#HB^3__X,X
M$75)Z-'D__^#PP%(@^P(2(T-2B$``$%44TV)Z5!-B?A(Q\+_____O@$```!(
MB>\QP.BCY___2(/$(+[``0``2(GOZ'+D__^#^/]TK4R)_^@EY/__2(T]SQ\`
M`$B)[C'`Z$3L__](B>_H?/G__^FW_?__#Q^``````$V+90#IL?[__P\?@```
M``")Q^@Y\O__2(7`28G%#X@%____2(UP]C'21(GGZ._F__](C;0D*@$``+H&
M````1(GGZ$KE__^+!0Q@```YA"0J`0``#X7/_O__#[<%_%\``&8YA"0N`0``
M#X6Z_O__2(V<)#`!``!)C77.,=)$B>?HG.;__[HH````2(G>1(GGZ/SD__](
MC05>(```QH0D6`$```!(C0T@(```3(T-&!\``+X!````38GX4%-(Q\+_____
M2(GO,<#HE.;__UE>Z0#___\/'T0``$V+;0A-A>T/A"/^__],B>_HX^/__TB#
M^`,/AA'^__])C70%_$B-/<(?``"Y!0```/.F#Y?`'`"$P$T/1.7I[OW__TF+
M30!(BST;A@``2(T5_!\``$V)^+X!````,<`Q[>CSY?__Z6[\___HF>/__V8/
M'X0``````$%455-(@^P0BSVBA0``9$B+!"4H````2(E$)`@QP.A]Y/__BSV'
MA0``2(G#Z&_D__\/MI.X````2(U<)`1(C3U8'@``2(G>B)"Y````,<#H+.G_
M_TB%P'0)@#@Q#X2N`0``,<#HE_7__XL]084``.@LY/__2(TU+1\``+D#````
MN@$```!(B<?HT^/__TB%P$B)Q70U2(M`$(L]$84``$R+(.CYX___2(T5_!X`
M`$B)QTR)YN@GX___2(M%$$B+*/9%#D`/A88!``"+/>"$``#HR^/__TB--=,>
M``"Y`P```+H!````2(G'Z'+C__](A<!(B<5T/4B-/6T=```QP$B)WNAYZ/__
M2(7`28G$#X0-`0``2(M%$(L]DX0``$B+*.A[X___3(GB2(G'2(GNZ*WB__^+
M/7>$``#H8N/__TB--6P>``"Z`0```$B)Q^ANX___BSU8A```2(G%Z$#C__](
MC15?'@``2(GN2(G'Z&[B__^+/3B$``#H(^/__TB-/=T<``#&@+D`````2(G>
M,<#HZ^?__TB%P$B)PTB)!6:$``!T/+[``0``2(G?Z#_A__^-4`&#^@%V"8/X
M$0^%J0```$B+1"0(9$@S!"4H````#X6R````2(/$$%M=05S#D$B+/2F$``#H
M%/?__TB%P$B)PTB)!0^$``!UJ4B-/6X>```QP.C'XO__#Q^``````(!X`0`/
MA$_^___I0_[__Y!(BP7I@P``BSV#@P``3(L@2(M%$$B+*.ADXO__3(GF2(GO
MZ`GM___IY_[__P\?0`"+/5J#``#H1>+__TB)[DB)Q^B:XO__Z5_^__^)P4B+
M!9R#``!(C3T='@``2(G:2(LP,<#H2.+__^@#X?__#Q\`55-(B?M(@^P(Z!+S
M__](B<?HVO+__TB)Q3'`Z.#T__^%P'0D2(7;=!^`.P!T&DB-/:8<``"Y!```
M`$B)[O.F#Y?`'`"$P'0(2(/$"%M=PY!(@\0(2(G?6UWI0NK__V:005=!5DR-
M3SA!54%413'`55-(@>R8`@``9$B+!"4H````2(F$)(@"```QP$B)X6:00XL$
M`4N+-`$/R$B)\HG`2,'J($J)!$%(B?!(P>XX2,'H*"4`_P``2`GP2(G62,'B
M"$C!YAB!X@``_P")]D@)\$@)T$J)1$$(28/`"$F#^$!UKDB-L0`"```/'X``
M````2(M!:$@S04!(@\$(2#-!"$@S0?A(C10`2,'H'T@)T(/@_TB)07A(.?%U
MU4R+%TB+7Q!(BW<@2(MO&$R+3PA,B=!,B=)(P>H;2,'@!4@)T`,$)(V4,)EY
M@EI(B=A(BW0D"$@QZ$PAR$@QZ$B-M#69>8):1(TL`DR)RDR)R$C!Z`)(P>(>
M2`G"2(G838GHB=%)P>@;2#'(3"'02#'82`'P3(GN2,'F!4P)QD2-)`9,B=9,
MB=!(P>8>2,'H`D@)\$B+="0038GC2#'"2<'K&T&)P$PAZDB-M#.9>8):2#'*
M2`'R3(GF2,'F!4P)WD2-'!9,B>Y(BU0D&$G![0)(P>8>3`GN2#'P2(V4$9EY
M@EI,B=E,(>!!B?9,,<!(P>D;2`'03(G:2,'B!4@)RDR)X4G![`)$C2P"2,'A
M'DB+5"0@3`GA2(GP2#'(3(GN08G,3"'828V4$)EY@EI(P>X;3#'P2`'03(GJ
M2,'B!4@)\D2-!`),B=I(BT0D*$G!ZP)(P>(>3`G:3(G&2#'128V$!IEY@EI(
MP>X;3"'I08G33#'A2`'!3(G`2,'@!4@)\$2--`A,B>A(BTPD,$G![0)(P>`>
M3`GH3(GV2#'"28V,#)EY@EI!B<5,(<),,=I(`<I,B?%(P>$%2,'N&T@)\4R)
MQDG!Z`)$C2012,'F'DB+5"0X3`G&2#'P3(GA08GP3"'P28V4$YEY@EI(P>D;
M3#'H2`'03(GB2,'B!4@)RDR)\4G![@)$C1P"2,'A'DB+5"1`3`GQ2(GP2#'(
M3(G>08G.3"'@28V4%9EY@EI(P>X;3#'`2`'03(G:2,'B!4@)\D2-+`),B>)(
MBT0D2$G![`)(P>(>3`GB3(GN2#'128V$`)EY@EI(P>X;3"'908G43#'Q2`'!
M3(GH2,'@!4@)\$2-!`A,B=A(BTPD4$G!ZP)(P>`>3`G83(G&2#'"28V,#IEY
M@EI(P>X;3"'J08G#3#'B2`'*3(G!2,'A!4@)\4R)[DG![0)$C3012,'F'DB+
M5"183`GN2#'P3(GQ08GU3"'`28V4%)EY@EI(P>D;3#'82`'03(GR2,'B!4@)
MRDR)P4G!Z`)$C20"2,'A'DB+5"1@3`G!2(GP2#'(3(GF08G(28V4$YEY@EI,
M(?!(P>X;3#'H2`'03(GB2,'B!4@)\D2-'`),B?)(BT0D:$C!XAY)P>X"3`GR
M3(G>2#'128V$!9EY@EI(P>X;3"'A08G63#'!2`'!3(G82,'@!4@)\$2-+`A,
MB>!(BTPD<$G![`)(P>`>3`G@3(GN2#'"28V,")EY@EI(P>X;3"':08G$3#'R
M2`'*3(GI2,'A!4@)\4R)WDG!ZP)$C0012,'F'DB+5"1X3`G>2#'P3(G!08GS
M3"'H28V4%IEY@EI(P>D;3#'@2`'03(G"2,'B!4@)RDR)Z4G![0)$C30"2,'A
M'DB+E"2`````3`GI2(GP2#'(3(GV08G-3"'`28V4%)EY@EI(P>X;3#'82`'0
M3(GR2,'B!4@)\D2-)`),B<)(BX0DB````$G!Z`)(P>(>3`G"3(GF2#'128V$
M`YEY@EI(P>X;3"'Q08G03#'I2`'!3(G@2,'@!4@)\$B+M"20````1(T<"$R)
M\$G![@)(P>`>3`GP28VT-9EY@EI-B=U(,<))P>T;B<%,(>),,<)(`?),B=Y(
MP>8%3`GNB?9(`?),B>9)P>P"2,'F'D&)U4P)YDR+I"28````2#'P3"'83XV$
M()EY@EI(,<A-B>Q)P>P;3`'`38GH2<'@!4T)X$6)P$P!P$V)V$G!ZP))P>`>
M08G$30G828GSB?9-,<-(`[0DJ````$0QVDR+G"2@````2HV,&:'KV6Y-B>-)
MP>L;2`'13(GB2,'B!4P)VHG22`'13(GJ2<'M`DC!XAY!B<M,">I-B<5%B<!)
M,=5,`X0DL````$0QZ$V)W4B-M`:AZ]EN3(G82<'M&TC!X`5,">B)P$@!\$R)
MYDG![`)(P>8>08G%3`GF28G4B=)),?1$,>%-B>Q(`Y0DN````$V-A`BAZ]EN
M3(GI2<'L&TC!X05,">&)R4D!R$R)V4G!ZP)(P>$>18G$3`G928GSB?9),<M(
M`[0DP````$0QV$V)XTB-E`*AZ]EN3(G@2<'K&TC!X`5,"=B)P$@!PDR)Z$G!
M[0)(P>`>08G33`GH28G-B<E),<5(`XPDR````$4QZ$V)W4Z-A`:AZ]EN3(G>
M2<'M&TC!Y@5,">Z)]DP!QDV)X$G![`))P>`>08GU30G@28G$B<!-,<1$,>)-
MB>Q(C8P1H>O9;DR)ZDC!X@5)P>P;2`.$)-````!,">*)TD@!T4R)VDG!ZP)(
MP>(>08G,3`G:38G#18G`23'33`.$)-@```!$,=Y-B>-(C;0PH>O9;DR)X$G!
MZQM(P>`%3`G8B<!(`?!,B>Y)P>T"2,'F'D&)PTP)[DF)U8G223'U2`.4).``
M``!$,>E-B=U-C80(H>O9;DR)V4G![1M(P>$%3`GIB<E)`<A,B>%)P>P"2,'A
M'D6)Q4P)X4F)](GV23',1#'@38GL2(V4`J'KV6Y,B>A)P>P;2,'@!4P)X(G`
M2`'"3(G82`.T).@```!)P>L"2,'@'D&)U$P)V$F)RXG)23'#2`.,)/````!%
M,=A-B>-.C80&H>O9;DR)YDG!ZQM(P>8%3`G>B?9,`<9-B>A)P>T"2<'@'D&)
M\TT)Z$F)Q8G`33'%2`.$)/@```!$,>I-B=U(C8P1H>O9;DR)VDG![1M(P>(%
M3`GJB=)(`=%,B>))P>P"2,'B'D&)S4P)XDV)Q$6)P$DQU$0QYDV)[$B-M#"A
MZ]EN3(GH2<'L&TC!X`5,">")P$@!\$R)WDC!YAY)P>L"3`.$)``!``!,"=Y)
MB=-!B<1),?.)TD@#E"0(`0``1#'938GC38V$"*'KV6Y,B>%)P>L;2,'A!4P)
MV8G)20'(3(GI2<'M`DC!X1Y%B<-,">E)B?6)]DDQS4@#M"00`0``1#'H38G=
M2(V4`J'KV6Y,B=A)P>T;2,'@!4P)Z(G`2`'"3(G@2<'L`DC!X!Y!B=5,">!)
MB<R)R4DQQ$4QX$V)[$Z-A`:AZ]EN3(GN2<'L&TC!Y@5,">:)]DP!QDV)V$G!
MZP))P>`>08GT30G82`.,)!@!``!)B<--,<.)P$@#A"0@`0``1#':38GC2<'K
M&TB-C!&AZ]EN3(GB2,'B!4P)VHG22`'13(GJ2<'M`DC!XAY!B<M,">I-B<5%
MB<!),=5,`X0D*`$``$0Q[DV)W4B-M#"AZ]EN3(G82<'M&TC!X`5,">B)P$@!
M\$R)YDG![`)(P>8>08G%3`GF28G4B=)),?1(`Y0D,`$``$0QX4V)[$V-A`BA
MZ]EN3(GI2<'L&TC!X05,">&)R4D!R$R)V4G!ZP)(P>$>18G$3`G928GSB?9)
M,<M$,=A-B>-(`[0D.`$``$B-E`*AZ]EN3(G@2<'K&TC!X`5,"=A$C1P03(GH
M2<'M`DC!X!Y,">A)B<V)R4DQQ8G"13'H38G=3HV$!J'KV6Y,B=Y)P>T;2,'F
M!4P)[DR+K"1``0``1HTT!DV)X$G![`))P>`>30G@3`G`1(G&28G$2(G02"'P
M32'<20G$N-R\&X])`<5,`>E-B?5)`<Q,B?%)P>T;2,'A!4P)Z4F)]4$!S$R)
MV4G!ZP)(P>$>3`G908G+20G(32'P32'=30GH3(NL)$@!``!)`<5,`>I-B>5)
M`=!,B>))P>T;2,'B!4P)ZD:-+`),B?))P>X"2,'B'DP)\DV)WD&)T$@)T4TA
MQDPAX4P)\4R+M"10`0``20'&3`'V38GN2`'Q3(GN2<'N&TC!Y@5,"?9$C30.
M3(GF2<'L`DC!YAY,">9-B<2)\4@)\DDAS$PAZDP)XDR+I"18`0``20'$30'C
M38GT3`':38GS2<'C!4G![!M-">-%C20338GK2<'M`DG!XQY-">M)B<U$B=I,
M"=Y)(=5,(?9,">Y,BZPD8`$``$D!Q4T!Z$V)Y4P!QDV)X$G![1M)P>`%30GH
M18TL,$V)\$G![@))P>`>30GP28G61(G&30G#22'V32'C30GS3(NT)&@!``!)
M`<9,`?%-B>Y)`<M,B>E)P>X;2,'A!4P)\4:--!E,B>%)P>P"2,'A'DP)X4F)
M]$&)RTD)R$TAZ$TAW$T)X$R+I"1P`0``20'$3`'B38GT20'03(GR2<'L&TC!
MX@5,">)&C20"3(GJ2<'M`DC!XAY,">I-B=U!B=!("=%-(<5,(?%,">E,BZPD
M>`$``$D!Q4P![DV)Y4@!\4R)YDG![1M(P>8%3`GN1(TL#DR)]DG![@)(P>8>
M3`GV38G&B?%("?))(<Y,(>),"?),B[0D@`$``$D!QDT!\TV)[DP!VDV)ZTG!
MXP5)P>X;30GS18TT$TV)XTG![`))P>,>30GC28G,1(G:3`G>22'43"'N3`GF
M3(ND)(@!``!)`<1-`>!-B?1,`<9-B?!)P>P;2<'@!4T)X$6-)#!-B>A)P>T"
M2<'@'DT)Z$F)U42)QDT)PTDA]4TA\TT)ZTR+K"20`0``20'%3`'I38GE20'+
M3(GA2<'M&TC!X05,">E&C2P93(GQ2<'N`DC!X1Y,"?%)B?9)"<A!B<M-(=Y-
M(>!-"?!,B[0DF`$``$D!QDP!\DV)[DD!T$R)ZDG![AM(P>(%3`GR1HTT`DR)
MXDG![`)(P>(>3`GB38G<08G02`G132'$3"'I3`GA3(ND)*`!``!)`<1,`>9-
MB?1(`?%,B?9)P>P;2,'F!4P)YD2-)`Y,B>Y)P>T"2,'F'DP)[DV)Q8GQ2`GR
M22'-3"'R3`GJ3(NL)*@!``!)`<5-`>M-B>5,`=I-B>-)P>T;2<'C!4T)ZT6-
M+!--B?-)P>X"2<'C'DT)\TF)SD2)VDP)WDDAUDPAYDP)]DR+M"2P`0``20'&
M30'P38GN3`'&38GH2<'N&TG!X`5-"?!%C30P38G@2<'L`DG!X!Y-">!)B=1$
MB<9-"<-)(?1-(>M-">-,BZ0DN`$``$D!Q$P!X4V)]$D!RTR)\4G![!M(P>$%
M3`GA1HTD&4R)Z4G![0)(P>$>3`GI28GU08G+20G(32'P32'=30GH3(NL),`!
M``!)`<5,`>I-B>5)`=!,B>))P>T;2,'B!4P)ZD:-+`),B?))P>X"2,'B'DV)
MV$P)\D&)UD@)T4TA\$PAX4P)P4R+A"3(`0``20'`3`'&38GH2`'Q3(GN2<'H
M&TC!Y@5,"<9$C00.3(GF2<'L`DC!YAY,B?%,">9!B?1("?),(>%,(>I("<I(
MBXPDT`$``$@!P4D!RTR)P4@#A"38`0``3`':38G#2,'A!4G!ZQM,"=F)R4P!
M\$@!RDR)Z4G![0)(P>$>08G33`GI38GE08G/2`G.32']3"'&3`GN38G=2`'P
M3(G>2<'M&TC!Y@5,">Z)]D@!\$R)QDG!Z`)(P>8>08G%20GPOM;!8LI,,<$Q
MRDB+C"3@`0``2`'Q20',3(GI3`'B38GL2,'A!4G![!M,">&)R4@!RDR)V4C!
MX1Y)P>L"08G420G+3(G!38GF3#'92<'N&T6)P#'(2(N,).@!``!(`?%)`<]*
MC0PX3(G@2,'@!4P)\(G`3(TT`4R)Z$G![0)(P>`>3(G918G;20G%2(N$)/`!
M``!%B?=,,>DQRDR)^4@!\$C!Z1M,`<!(`<),B?A(P>`%2`G(2(N,)/@!``")
MP$@!PDR)X$G![`)(P>`>2`'Q08G03`G@3`'938GK23'#38G$18GM13'>2<'L
M&TZ-'#%,B<%(P>$%3`GAB<E)`<M,B?E)P>\"2,'A'D6)W$D)STB+C"0``@``
M2`'Q3`'I28G%B<!-,?U$,>I,C2P13(GB3(GA2,'I&TC!X@5("<I,B<%)P>@"
MB=)(P>$>20'52(N4)`@"``!,"<%-B?A%B>Y%B?]),<A(`?)%,<-(`=!,B?).
MC0083(GP2,'J&TC!X`5("=!(B<J)R8G`20'`3(G@2<'L`DC!X!Y%B<-)"<1(
MBX0D$`(``$PQXD$QU4R)VD@!\$P!^$D!Q4R)V$C!X`5(P>H;2`G03(GR2<'N
M`HG`2,'B'DD!Q4B+A"08`@``3`GR18GO2`'P2`'(3(GA18GD2#'103'(3(GY
M20'`3(GX2,'I&TC!X`5("<B)P$D!P$R)V$G!ZP)(P>`>18G&20G#2(N$)"`"
M``!,B?%(P>D;2`'P3`'@28G4B=)-,=Q%,>5.C20H3(GP2,'@!4@)R$B+C"0H
M`@``B<!)`<1,B?A)P>\"2`'Q2,'@'D6)Y4P)^$@!RDR)V4@QP46)VT$QR$R)
MZ4D!T$R)ZDC!Z1M(P>(%2`G*B=))`=!,B?))P>X"2,'B'D6)QTD)UDB+E"0P
M`@``3(GY2,'I&T@!\DP!VDF)PXG`33'S13'<3HT<(DR)^DC!X@5("<I,B>E)
MP>T"B=)(P>$>20'32(N4)#@"``!,">E%B=Q(`?)(`=!,B?)%B?9(,<I!,=!,
MB>))`<!,B>!(P>H;2,'@!4@)T$B)RHG)B<!)`<!,B?A)P>\"2,'@'D6)Q4D)
MQTB+A"1``@``2`'P3#'Z3`'P03'33(GJ20'#3(GH2,'J&TC!X`5("=!,B>))
MP>P"B<!(P>(>20'#2(N$)$@"``!,">)%B=Y)B=1(`?!(`<A,B?E%B?](,=&)
MTD$QR$J-#`!,B?!-B?!)P>@;2,'@!4P)P(G`2`'!3(GH2<'M`DC!X!Y!B<A)
M"<5(BX0D4`(``$TQ[$4QXTV)Q$@!\$G![!M,`?A)`<-,B<!(P>`%3`G@B<!)
M`<-,B?!(P>`>2<'N`D6)W$P)\$R+M"18`@``20'V20'63(GJ18GM2#'",=%)
MC10.3(GA38GF2<'N&TC!X05,"?&)R4@!RDR)P4G!Z`)(P>$>08G620G(2(N,
M)&`"``!(`?%,`>E)B<6)P$TQQ44QZTV)]4D!RTR)\4G![1M(P>$%3`GIB<E)
M`<M,B>%)P>P"2,'A'D6)W4D)S$B+C"1H`@``2`'Q2`'(3(G!18G`3#'A,<I(
MC0P03(GH3(GJ2,'J&TC!X`5("=!,B?))P>X"2,'B'HG`20G62(N4)'`"``!(
M`<&)R$@!\DP!PDV)X$TQ\$4QPTF)P$P!VDF)PTG!X`5)P>L;30G828G#2,'H
M`DG!XQY!`=!,B>I)"<-(BX0D>`(``$C!XAY)P>T"00';20G51(GB3(E?$$@!
M\$0![4@!PDR)\$B);QA,,>@QP4B-!`I,B<),B<%(P>(%2,'I&T4!R$@)RDR)
M1P@!T$$!PD0#=R!(BX0DB`(``&1(,P0E*````$R)%TR)=R!U$DB!Q)@"``!;
M74%<05U!7D%?P^B2RO__9I!(@^P(OX````#HHLO__[J)J\WON?[<NIB^\.'2
MPTC'``$C16=(B5`(2(E($$C'0!AV5#(02(EP($C'0"@`````2,=`,`````#'
M0'@`````2(/$",-F9BX/'X0``````)!!5T%62&/"055!5$F)Q5532(GS28G\
M2(/L"$B+=RA(BU<P28UL)#B-#,9(.?%(B4\H2(/2`$C!Z!U(`=!(B4<P2&-_
M>(7_=%A!OT````!(B=Y!*?]%.?U%#T[]2`'O36/W3(GRZ*?*__]!BT0D>$0!
M^(/X0$&)1"1X=!5(@\0(6UU!7$%=05Y!7\-F#Q]$``!,B>=%*?U,`?/H\NC_
M_V:008/]/WY508/M0$6)[T'![P9%B?Y)@\8!2<'F!DD!WI#S#V\#3(GG2(/#
M0`\110#S#V]#T`\111#S#V]#X`\112#S#V]#\`\113#HH>C__TPY\W7,0<'G
M!D4I_4ECQ4B#^`AR7$B+$TF)5"0X2(M4`_A(B50%^$B-50A(@^+X2"G52"GK
M2`'%2(/E^$B#_0AR%TB#Y?@QP$B+#`-(B0P"2(/`"$@YZ'+O18EL)'A(@\0(
M6UU!7$%=05Y!7\,/'T``J`1U'4B%P'3?#[83J`)!B%0D.'33#[=4`_YFB50%
M_NO'BQ-!B50D.(M4`_R)5`7\Z[9F9BX/'X0```````\?`$%6055,C78X0515
M2(G]4TR+9BA(B?-,BVXP3(G@2,'H`X/@/XU(`4B8QD0&.(!(8\%,`?"#^3@/
MCYL!``"Z.````#'V*<J#^@@/@F$!``")T4C'``````!(QT0(^`````!(C4@(
M2(/A^$@IR`'"@^+X@_H(<A*#XO@QP(G'@\`(.=!(B30Y<O-,B>A$B&MS1(AC
M=TC!Z!A(B=^(0W!,B>A(P>@0B$-Q3(GH2,'H"(A#<DR)X$C!Z!B(0W1,B>!(
MP>@0B$-U3(G@2,'H"(A#=N@<Y___2(L#2(G?2,'H&(A%`$B+`TC!Z!"(10%(
MBP-(P>@(B$4"2(L#B$4#2(M#"$C!Z!B(101(BT,(2,'H$(A%!4B+0PA(P>@(
MB$4&2(M#"(A%!TB+0Q!(P>@8B$4(2(M#$$C!Z!"(10E(BT,02,'H"(A%"DB+
M0Q"(10M(BT,82,'H&(A%#$B+0QA(P>@0B$4-2(M#&$C!Z`B(10Y(BT,8B$4/
M2(M#($C!Z!B(11!(BT,@2,'H$(A%$4B+0R!(P>@(B$422(M#((A%$UM=05Q!
M74%>Z0C&__\/'X0``````/;"!'5KA=(/A,O^___VP@+&```/A+_^__\QR6:)
M3!#^Z;/^__\/'P"Z0````"G*=`\QR8G.@\$!.='&!#``<O-(B=_H^.7__V8/
M[\`/$4,X2<=&,`````!!#Q%&$$$/$48@Z7'^__]F#Q^$``````#'``````#'
M1!#\`````.E5_O__9BX/'X0```````\?`)"0D)"0D)"0D)"0D)"0D)!!5T%6
M28G7055!5$R-)9YC``!52(TMGF,``%-!B?U)B?9,*>5(@^P(2,']`^C_Q/__
M2(7M="`QVP\?A```````3(GZ3(GV1(GO0?\4W$B#PP%(.=UUZDB#Q`A;74%<
M05U!7D%?PV9F+@\?A```````D)"0D)"0D)"0D)"0D)"0D//#9BX/'X0`````
M``\?0`"0D)"0D)"0D)"0D)"0D)"02(L-@6<``.D4QO__2(/L"$B#Q`C#````
M`0`"`"XN`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z.F)O;W1?
M1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E<P!0
M05)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,24(`4$52
M3#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?
M0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%0E5'`%!!
M4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]414U0`%!!
M4E]'3$]"04Q?0TQ%04X`,0!,1%],24)205)97U!!5$@`55-%4@!365-414T`
M+W1M<`!414U01$E2`%1-4`!54T523D%-10`E,#)X`"5S)7,E<R5S`'!A<BT`
M<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E
M;7`M)74M)74E<P`8`'!E<FP`,`!005(Z.E!A8VME<CHZ5D524TE/3@`Q+C`U
M-P`M90`M+0`````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R:79A=&4@
M<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A
M;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````%5N86)L92!T;R!C<F5A
M=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*
M``````````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB
M)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A
M8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O9F9S971?
M<VEZ92P@)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-04=)0R`]
M(")<;E!!4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@(",@<&%C
M:R@B3B(I"B1C86-H95]N86UE7W-I>F4@/2`T,#L*)%!+6DE07TU!1TE#(#T@
M(E!+7#`P,UPP,#0B.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY("@D9F@I
M(#T@0%\["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM
M>2`D<VEZ92`]("US("1F:#L*;7D@)'!O<R`]("@D<VEZ92TQ*2`M("@D<VEZ
M92TQ*2`E("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@)'!O<R!I<R!A(&UU
M;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I('L*<V5E
M:R`D9F@L("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D8VAU;FM?<VEZ92`K
M(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F
M+"`D4$%27TU!1TE#*2D@/CT@,"D@>PIR971U<FX@)'!O<R`K("1I.PI]"B1P
M;W,@+3T@)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D<&%R7W1E
M;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![
M(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY
M("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I
M.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I
M;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N
M;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D
M<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W
M($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&
M:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N
M8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I
M;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@
M+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D
M<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD
M>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H
M;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D
M978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE
M9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL
M96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I
M(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A
M<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM
M>2`E<WES(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@
M)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN
M?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@
M*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P
M<F]G;F%M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI
M.PI?<V5T7W!A<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@
M(B1%3E9[4$%27U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)'-T87)T7V]F
M7T9)3$5?<V5C=&EO;BD["DU!1TE#.B!["FQO8V%L("1324=[7U]705).7U]]
M(#T@<W5B('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA
M;64I('L*;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R;V=N86UE
M(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E<R!%<G)N
M;RYP;0IL87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M
M86=I8R@J7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N
M)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I;&4@(B1P
M<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!005(@;6%G
M:6,@870@<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA9VEC
M7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@;&5N9W1H*")<,$-!0TA%(BDL
M(#`["G)E860@7T9(+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B
M=68@;F4@(EPP0T%#2$4B("8F("1B=68@;F4@(EPP0TQ%04XB*2!["F]U=',H
M(DYO(&-A8VAE(&UA<FME<B!F;W5N9"(I.PIL87-T($U!1TE#.PI]"F]U=',H
M<7%;0V%C:&4@;6%R:V5R("(D8G5F(B!F;W5N9%TI.PIS965K(%]&2"P@)&UA
M9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&2"P@)&)U
M9BP@)$9)3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A8VLH(DXB
M+"`D8G5F*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,17,@:7,@
M)&]F9G-E="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E
M=%]S:7IE("T@)&]F9G-E="P@,#L*)'-T87)T7V]F7T9)3$5?<V5C=&EO;B`]
M('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@
M-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T
M(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@
M)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U
M;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA
M+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D
M97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@
M7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U
M9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L
M?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E
M>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L
M;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F
M:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@
M;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM
M>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&)A<V5N86UE)&5X="(L("1B=68L
M(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*
M)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@
M/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[
M)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)
M3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@
M:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L
M94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@
M)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A
M9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D
M969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D
M(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D[
M"B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I
M;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[
M8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H
M+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F
M:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I
M;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)
M3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E
M<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I
M;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E
M7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE
M;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D
M+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M
M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]
M"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U
M9B!N92`D4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T
M97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-
M04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@
M("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O
M=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.
M5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@
M<V5C=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP
M72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M
M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U
M;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII
M9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`
M05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L
M<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*
M=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S
M5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D
M7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@
M)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L
M("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF
M("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@
M97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G
M*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L
M;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@
M(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@
M/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD
M>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*
M<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL
M97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6
M.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF
M("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E
M.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T
M*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY
M("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@
M9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II
M<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA
M;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R
M(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*
M;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D
M>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A
M<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H
M6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P
M96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D
M('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U
M9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S
M("1B=68@97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@["GT*0W)E871E4&%T
M:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&
M:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL
M93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@
M9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P
M+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S
M96-T:6]N*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S
M96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@
M/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@
M/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R
M+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@
M=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2![
M"G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO
M861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN
M8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I
M=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N
M9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,[
M"G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F
M:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S
M+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[
M;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY
M("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I
M('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I
M(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN
M8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M
M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U
M;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL
M87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H
M(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F
M:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I
M9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I
M.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@
M)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0[
M"FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]
M"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W
M)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD
M8V]N=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13
M=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF
M("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX
M?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L
M>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,
M12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P
M.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL
M("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N
M="D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D960@1DE,12!T;R`B
M)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]
M"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@
M07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z
M:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2![
M"B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D969I;F5D
M("1C86-H95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I
M.PIS965K("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D9F@I.PIS965K("1F
M:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A
M8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H95]N86UE
M7W-I>F4["B1C86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ
M92`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA
M;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE
M;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E="DL
M"B1005)?34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET
M:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70[
M"F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F
M:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@
M07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E
M<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G
M<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ
M6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z
M.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R
M;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%
M<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV
M93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,
M:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z
M:7`["F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%
M3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT
M(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT
M(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D
M;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^
M(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_
M"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX
M.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE
M.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE
M*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O
M;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N
M86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=
M*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B
M('1O("(D9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C=%1O1FEL
M94YA;65D*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*
M;W(@9&EE('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T;R`B)&1E
M<W1?;F%M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@
M(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N
M86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@
M+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@
M72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C
M+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@
M<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]
M($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D
M<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE
M+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ
M;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S
M('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L
M:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U
M:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR
M97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R
M;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R
M.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@
M1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<[
M"G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER
M92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I
M<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A
M=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0
M;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR
M97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L
M('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T
M:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T[
M"F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V
M86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!]
M.PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@
M>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-
M4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R
M96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2
M(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M
M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P
M871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V
M86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*
M:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE
M(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED
M*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@
M)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0IM
M>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B
M2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;7D@)&-A
M8VAE7V1I<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?9&ER(#T@
M(G1E;7`M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R
M;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T[
M"FEF("@H;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F:"DI(#X]
M(#`I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ
M90HM(&QE;F=T:"@B7#!#04-(12(I+"`P.PIM>2`D8G5F.PIR96%D("1F:"P@
M)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&5Q(")<,$-!0TA%
M(BD@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE
M"BT@;&5N9W1H*")<,$-!0TA%(BD*+2`D8V%C:&5?;F%M95]S:7IE+"`P.PIR
M96%D("1F:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]?B!S+UPP
M+R]G.PHD8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO<V4@)&9H
M.PI]"FEF("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B
M.PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D<WES>U]D
M96QI;7TD8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["B1%3E9[
M4$%27U1%35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@
M:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI
M+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO
M9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU
M;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN
M86UE+B0D(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M
M92D*)B8@*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R
M(&1I92!Q<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D
M("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T
M96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR
M971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E
M9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-
M17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\
M?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE
M+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H
M)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@
M,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N
M86UE+"`D<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G
M/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B
M)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X
M97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y
M<WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@
M)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D
M:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D
M9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II
M9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH
M*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA
M<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U
M8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%2
M7U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]
M*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B
M.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG
M971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ
M1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@
M<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]
M+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R
M7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q
M("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`]
M(#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%
M(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@
M*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D
M7R)](#T@)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)0
M05)?1TQ/0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T
M92`D14Y6>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D
M<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE
M;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER
M92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I
M9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E
M87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP
M"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#
M+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I
M92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M
M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P
M<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@
M/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z
M.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ
M7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T52
M4D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*````````0T%#2$4``'!E
M<FQX<VDN8P````$;`SL0`0``(0```(2#__]<`0``!(?__X0!```4A___*`8`
M`%2)__\L`0``9(K__YP!```TB___Z`$``,2+__\4`@``%([__V`"``"4C___
MK`(``#20___0`@``%)'__Q0#``#DD?__1`,``.22__]\`P``%)/__Y0#``!D
MD___K`,``#24___8`P``1)3__^P#``!DEO__3`0``)26__]H!```Y);__XP$
M``!TF/__L`0``-28___,!```!)G__^@$``#DF?__*`4``.2@___`!0``=*/_
M__0%``#4H___5`8``.2Y__^D!@``1+K__[P&``#DN___(`<``#*^__]D!P``
MLK[__ZP'``#2OO__Q`<``!0``````````7I2``%X$`$;#`<(D`$'$!0````<
M````((C__RL``````````````!0``````````7I2``%X$`$;#`<(D`$``"0`
M```<````((+__X`#````#A!&#AA*#PMW"(``/QH[*C,D(@`````4````1```
M`'B%__\(``````````````!(````7````,"(___,`````$(.$(\"0@X8C@-"
M#B"-!$(.*(P%00XPA@9!#CB#!T0.0`)L"@XX1`XP00XH0@X@0@X80@X00@X(
M20L`*````*@```!$B?__A`````!!#A"&`D$.&(,#1PXP`G,*#AA!#A!!#@A!
M"P!(````U````*B)__],`@```$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!
M#CB#!TH.8`,F`0H..$$.,$$.*$(.($(.&$(.$$(."$0+2````"`!``"LB___
M>0$```!"#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX@P='#O`!?@H..$$.
M,$$.*$(.($(.&$(.$$(."$<+`"````!L`0``X(S__Y0`````00X0@P)2#K`!
M`E,*#A!!#@A)"T````"0`0``7(W__]X`````0@X0C@)"#AB-`T4.((P$00XH
MA@5$#C"#!E,.P"`"A`H.,$$.*$$.($(.&$(.$$(."$,++````-0!``#XC?__
MQ`````!!#A"#`D\.H"`">@H.$$$."$4+8@H.$$@."$4+````-`````0"``"8
MCO__\@````!"#A",`D$.&(8#1@X@@P1,#K"`!`*L"@X@00X800X00@X(2PL`
M```4````/`(``&"/__\P`````$0.$&<."``4````5`(``'B/__])`````$0.
M$'T."``H````;`(``+"/___!`````$$.$(8"00X8@P-'#L!``J<*#AA!#A!!
M#@A&"Q````"8`@``5)#__P4`````````7````*P"``!0D/__&@(```!"#A"/
M`D(.&(X#0@X@C01"#BB,!40.,(8&00XX@P=1#O`A`F0*#CA!#C!!#BA"#B!"
M#AA"#A!"#@A$"P*Q#O@A3PZ`(FH.^"%!#O`A````&`````P#```0DO__(@``
M``!!#A"#`EP."````"`````H`P``))+__T0`````2PX0@P)8PPX(70X0@P)#
M#@@``"````!,`P``4)+__X8!````00X0@P)+#B`#1`$*#A!!#@A'"Q@```!P
M`P``O)/__UT`````1`X@`E,*#@A!"P`8````C`,```"4__\D`````$0.$%@*
M#@A$"P``/````*@#```4E/__W`````!"#A",`D$.&(8#1`X@@P1+#C`"6`XX
M3PY`;@XX00XP:@H.($$.&$$.$$(."$$+`)0```#H`P``M)3___<&````0@X0
MCP)"#AB.`T(.((T$0@XHC`5$#C"&!D$..(,'3@ZP`P,8`@ZX`U(.P`-G#K@#
M0@ZP`P,3`0H..$$.,$$.*$(.($(.&$(.$$(."$4+`W(!#K@#2`[``V$.N`-!
M#K`#6@ZX`TD.P`-!#L@#1`[0`UT.L`,"^0ZX`T$.P`-2#K@#00ZP`P``,```
M`(`$```<F___C0(```!"#A",`D$.&(8#00X@@P1$#C`#T@$*#B!!#AA!#A!"
M#@A""S````"T!```>)W__UX`````00X0A@)!#AB#`T<.(`)#"@X800X000X(
M0@M$#AA$#A!!#@@H````Z`0``.2`__\T`@```$$.$(8"00X8@P-$#E`#M@$*
M#AA!#A!!#@A!"TP````4!0``>)W__PX6````0@X0CP)"#AB.`T8.((T$0@XH
MC`5$#C"&!D$..(,'1P[0!0/F%0H..$$.,$$.*$(.($(.&$(.$$(."$$+````
M%````&0%```XL___5`````!$#A`"3PX(8````'P%``"`L___D@$```!"#A"/
M`D(.&(X#10X@C01"#BB,!40.,(8&00XX@P=*#D`"90H..$$.,$$.*$(.($(.
M&$(.$$(."$<+`L$*#CA!#C!!#BA"#B!"#AA"#A!"#@A%"T````#@!0``O+3_
M_S,"````0@X0C@)"#AB-`T8.((P$00XHA@5$#C"#!@.-`0H.*$$.($(.&$(.
M$$(."$T+````````1````"0&``#&MO__9P````!$#A"/`D(.&(X#10X@C01"
M#BB,!4@.,(8&2`XX@P=-#D!R#CA!#C!!#BA"#B!"#AA"#A!"#@@`%````&P&
M``#^MO__!```````````````$````(0&```&M___#@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"0```````#`(P````````````````````````````````````````$`````
M`````@,````````!``````````T#`````````0`````````=`P```````!T`
M````````J`0````````,`````````!`=````````#0````````",6```````
M`!D`````````D+L````````;``````````@`````````&@````````"8NP``
M`````!P`````````"``````````$`````````)@"````````]?[_;P````"P
M!0````````4`````````X`\````````&`````````+`&````````"@``````
M``#=!`````````L`````````&``````````5`````````````````````P``
M``````#HO0````````(`````````*`4````````4``````````<`````````
M%P````````#H%P````````<`````````"!8````````(`````````.`!````
M````"0`````````8`````````!X`````````"`````````#[__]O``````$`
M``@`````_O__;P````"(%0```````/___V\``````@````````#P__]O````
M`+X4````````^?__;P`````'````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````N+L`````````````````````````````1AT`````
M``!6'0```````&8=````````=AT```````"&'0```````)8=````````IAT`
M``````"V'0```````,8=````````UAT```````#F'0```````/8=````````
M!AX````````6'@```````"8>````````-AX```````!&'@```````%8>````
M````9AX```````!V'@```````(8>````````EAX```````"F'@```````+8>
M````````QAX```````#6'@```````.8>````````]AX````````&'P``````
M`!8?````````)A\````````V'P```````$8?````````5A\```````!F'P``
M`````'8?````````AA\```````"6'P```````*8?````````MA\```````#&
M'P```````-8?````````YA\```````#V'P````````8@````````%B``````
M```F(````````#8@````````1B````````!6(````````&8@````````=B``
M``````"&(````````)8@````````IB``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````C`````````"E!!4BYP;0H``````````'!;
M````````T%<```````!06````````'!8````````1T-#.B`H4U5312!,:6YU
M>"D@-RXU+C```"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI
M9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N
M=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`
M+FEN:70`+G!L="YG;W0`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?
M:&1R`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9&%T82YR
M96PN<F\`+F1Y;F%M:6,`+F1A=&$`7U]P871C:&%B;&5?9G5N8W1I;VY?96YT
M<FEE<P`N8G-S`"YC;VUM96YT````````````````````````````````````
M```````````````````````````````````````````````````+`````0``
M``(`````````.`(````````X`@```````!P````````````````````!````
M````````````````$P````<````"`````````%0"````````5`(````````D
M````````````````````!````````````````````"8````'`````@``````
M``!X`@```````'@"````````(`````````````````````0`````````````
M```````X````!0````(`````````F`(```````"8`@```````!0#````````
M!@`````````(``````````0`````````-````/;__V\"`````````+`%````
M````L`4``````````0````````8`````````"````````````````````#X`
M```+`````@````````"P!@```````+`&````````,`D````````'`````0``
M``@`````````&`````````!&`````P````(`````````X`\```````#@#P``
M`````-T$```````````````````!````````````````````3@```/___V\"
M`````````+X4````````OA0```````#$``````````8``````````@``````
M```"`````````%L```#^__]O`@````````"(%0```````(@5````````@```
M```````'`````@````@```````````````````!J````!`````(`````````
M"!8````````(%@```````.`!````````!@`````````(`````````!@`````
M````=`````0```!"`````````.@7````````Z!<````````H!0````````8`
M```8````"``````````8`````````'X````!````!@`````````0'0``````
M`!`=````````%P````````````````````0```````````````````!Y````
M`0````8`````````,!T````````P'0```````(`#```````````````````0
M`````````!``````````A`````$````&`````````+`@````````L"``````
M```(````````````````````"``````````(`````````(T````!````!@``
M``````#`(````````,`@````````S#<``````````````````!``````````
M``````````"3`````0````8`````````C%@```````",6`````````D`````
M```````````````$````````````````````F0````$````"`````````)A8
M````````F%@````````200``````````````````"```````````````````
M`*$````!`````@````````"LF0```````*R9````````%`$`````````````
M``````0```````````````````"O`````0````(`````````P)H```````#`
MF@```````,@&```````````````````(````````````````````N0````X`
M```#`````````)"[````````D*L````````(````````````````````"```
M```````(`````````,4````/`````P````````"8NP```````)BK````````
M"`````````````````````@`````````"`````````#1`````0````,`````
M````H+L```````"@JP```````!,````````````````````0````````````
M````````W@````8````#`````````+B[````````N*L````````P`@``````
M``<`````````"``````````0`````````(@````!`````P````````#HO0``
M`````.BM````````$`(```````````````````@`````````"`````````#G
M`````0````,``````````,``````````L````````"@`````````````````
M```(````````````````````[0````$```"#`````````"C`````````*+``
M```````8``````````\`````````"`````````````````````H!```(````
M`P````````!`P````````$"P````````<````````````````````"``````
M```````````````/`0```0```#````````````````````!`L````````!@`
M```````````````````!``````````$``````````0````,`````````````
M````````````6+`````````8`0```````````````````0``````````````
$````````
